@@ -1,6 +1,6 @@
 import pandas as pd
 import click
-from xpandas.execute import *
+from xpandas.module import *
 
 
 def get_cmd():
